from django import views
from django.shortcuts import render
from .models import *
from .serializers import *
from rest_framework import viewsets,views
from rest_framework.response import Response
import os
import csv
import sys

#from sitcomm.conf import *

class UserViewSet(viewsets.ModelViewSet):
    queryset = Users.objects.all()
    serializer_class = UserSerializer

class ProjectViewSet(viewsets.ModelViewSet):
    queryset = Projects.objects.all()
    serializer_class = ProjectSerializer

class AccessViewSet(viewsets.ModelViewSet):
    queryset = Access.objects.all()
    serializer_class = AccessSerializer

class JiraViewSet(viewsets.ModelViewSet):
    queryset = Tickets.objects.all()
    serializer_class = JiraSerializer

# Create your views here.

class checkAuthViewSet(views.APIView):
    def get(self,request):
        uid = request.GET.get('uid')
        try:
            user = Users.objects.get(uid=uid)
            return Response({'status':True})
        except:
            return Response({'status':False})

class authenticateViewSet(views.APIView):
    def post(self,request):
        email = request.data.get('email')
        password = request.data.get('password')
        try:
            user = Users.objects.get(email=email,password=password)
            if user is None:
                return Response({'status':False})
            status = Users.objects.update(email=email,password=password,active=True)
            return Response({'email':email,'status':bool(status)})
        except:
            return Response({'status':False})

class registerViewSet(views.APIView):
    def post(self,request):
        email = request.data.get('email')
        password = request.data.get('password')
        role = request.data.get('role')
        try:
            user = Users.objects.create(email=email,password=password,role=role,active=True)
            return Response({'uid':user.uid,'status':True})
        except:
            return Response({'status':False})

class getJiraTicketsViewSet(views.APIView):
    def get(self,request):
        pid = request.GET.get('pid')
        try:
            project = Projects.objects.filter(pid=pid)
            if project is None:
                return Response({'status':False})
            return Response({'files':project.values('jira_id'),'status':True})
        except Exception as e:
            print(e)
            return Response({'status':False})

class getJiraBoardViewSet(views.APIView):
    def get(self,request):
        pid = request.GET.get('pid')
        status = 'All'
        try:
            if request.GET.get('status') is not None:
                col_name = request.GET.get('status')
        except:
            pass
        try:
            project = Projects.objects.filter(pid=pid)
            if project is None:
                return Response({'status':False})
            tickets = Tickets.objects.filter(pname=pid)
            if tickets is None:
                return Response({'status':False})
            if col_name != 'All':
                tickets = tickets.filter(status=status)
            return Response({'tickets':tickets.values(),'status':True})
        except Exception as e:
            print(e)
            return Response({'status':False})


class createJiraTicketViewSet(views.APIView):
    def post(self,request):
        pid = request.data.get('pid')
        name = request.data.get('name')
        content = request.data.get('content')
        status = request.data.get('status')
        try:
            ticket = Tickets.objects.create(pid=pid,name=name,content=content,status=status)
            return Response({'tid':ticket.tid,'status':True})
        except Exception as e:
            print(e)
            return Response({'status':False})

class updateJiraTicketViewSet(views.APIView):
    def post(self,request):
        tid = request.data.get('tid')
        name = request.data.get('name')
        content = request.data.get('content')
        status = request.data.get('status')
        try:
            ticket = Tickets.objects.filter(tid=tid)
            if ticket is None:
                return Response({'status':False})
            ticket.update(name=name,content=content,status=status)
            return Response({'status':True})
        except Exception as e:
            print(e)
            return Response({'status':False})



class getReposViewSet(views.APIView):
    def get(self,request):
        uid = request.GET.get('uid')
        try:
            user = Users.objects.get(uid=uid)
            if user is None:
                return Response({'status':False})
            access = Access.objects.filter(uid=user).values('pid').distinct()
            try:
                repos = Projects.objects.filter(pid__in=access)
                #print("Projects",Projects.objects.values())
            except Exception as e:
                print(e)
            return Response({'repos':repos.values(),'status':True})
        except:
            return Response({'status':False})

class getGitFilesViewSet(views.APIView):
    def get(self,request):
        pid = request.GET.get('pid')
        try:
            project = Projects.objects.filter(pid=pid)
            if project is None:
                return Response({'status':False})
            return Response({'files':project.values('git_id'),'status':True})
        except Exception as e:
            print(e)
            return Response({'status':False})

class postFileChangeViewSet(views.APIView):
    def post(self,request):
        pid = request.data.get('pid')
        file = request.data.get('file')
        data = request.data.get('data')
        try:
            project = Projects.objects.filter(pid=pid)
            if project is None:
                return Response({'status':False})
            git_id = project.values('git_id')[0]['git_id']
            with open (git_id,'a') as f:
                csvFile = csv.reader(f)
                for row in csvFile:
                    if row[0] == file:
                        row[1] = data
                        break
                writer = csv.writer(f)
                writer.writerow(row)
            return Response({'status':True})
        except Exception as e:
            print(e)
            return Response({'status':False})

class postFileCreateViewSet(views.APIView):
    def post(self,request):
        pid = request.data.get('pid')
        file = request.data.get('file')
        data = request.data.get('data')
        try:
            project = Projects.objects.filter(pid=pid)
            if project is None:
                return Response({'status':False})
            git_id = project.values('git_id')[0]['git_id']
            with open (git_id,'a') as f:
                writer = csv.writer(f)
                writer.writerow([file,data])
            return Response({'status':True})
        except Exception as e:
            print(e)
            return Response({'status':False})


class getUserDetailsViewSet(views.APIView):
    def get(self,request):
        uid = request.GET.get('uid')
        try:
            user = Users.objects.filter(uid=uid)
            if user is None:
                return Response({'status':False})
            return Response({'user':user.values(),'status':True})
        except Exception as e:
            print(e)
            return Response({'status':False})

    
class postUserDetailsViewSet(views.APIView):
    def post(self,request):
        uid = request.data.get('uid')
        email = request.data.get('email')
        password = request.data.get('password')
        role = request.data.get('role')
        profile_img = request.data.get('profile_img')
        try:
            user = Users.objects.filter(uid=uid)
            if user is None:
                return Response({'status':False})
            status = user.update(email=email,password=password,role=role,profile_img=profile_img)
            return Response({'status':bool(status)})
        except Exception as e:
            print(e)
            return Response({'status':False})

class getConfluencePagesViewSet(views.APIView):
    def get(self,request):
        pid = request.GET.get('pid')
        try:
            project = Projects.objects.filter(pid=pid)
            if project is None:
                return Response({'status':False})
            return Response({'pages':project.values('confluence_id'),'status':True})
        except Exception as e:
            print(e)
            return Response({'status':False})
